# mjc_viewer

`mjc_viewer` is a browser-based 3D viewer that can render static trajectories from JSON.

## Installation

The recommended way to install this package is via [PyPI](https://pypi.org/project/mjc_viewer/):

```bash
pip install --upgrade mjc_viewer
```

## Acknowledgements

`mjc_viewer` is heavily adapted from [Brax](https://github.com/google/brax)'s javascript viewer, full credit goes to its developers.
